summaryrefslogtreecommitdiff
path: root/flake.nix
diff options
context:
space:
mode:
Diffstat (limited to 'flake.nix')
-rw-r--r--flake.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/flake.nix b/flake.nix
index c7187339..34df58dc 100644
--- a/flake.nix
+++ b/flake.nix
@@ -37,9 +37,9 @@
craneLib = crane.mkLib pkgs;
# Typst files to include in the derivation.
# Here we include Rust files, assets and tests.
src = sourceByRegex ./. [
- "(assets|crates|tests)(/.*)?"
+ "(docs|crates|tests)(/.*)?"
''Cargo\.(toml|lock)''
''build\.rs''
];
@@ -37,9 +37,9 @@
craneLib = crane.mkLib pkgs;
# Typst files to include in the derivation.
- # Here we include Rust files, assets and tests.
+ # Here we include Rust files, docs and tests.
src = sourceByRegex ./. [